@@ -11,10 +11,7 @@ package Dist::Zilla::Plugin::Git::CheckFor::CorrectBranch;
 BEGIN {
   $Dist::Zilla::Plugin::Git::CheckFor::CorrectBranch::AUTHORITY = 'cpan:RSRCHBOY';
 }
-{
-  $Dist::Zilla::Plugin::Git::CheckFor::CorrectBranch::VERSION = '0.008';
-}
-
+$Dist::Zilla::Plugin::Git::CheckFor::CorrectBranch::VERSION = '0.009';
 # ABSTRACT: Check that you're on the correct branch before release
 
 use Moose;
@@ -57,7 +54,7 @@ sub before_release {
     $self->log_fatal($fatal_msg) if $fatal_msg;
 
     # if we're here, we're good
-    $self->log("Current branch ($cbranch) and release branch match (", join(', ', @rbranch), ")");
+    $self->log("Current branch ($cbranch) and release branch match (" . join(', ', @rbranch) .')');
     return;
 }
 
@@ -71,8 +68,9 @@ __END__
 
 =encoding UTF-8
 
-=for :stopwords Chris Weyl Karen Etheridge Mike Doherty Olivier Mengué <ether@cpan.org>
-<doherty@cs.dal.ca> <dolmen@cpan.org>
+=for :stopwords Chris Weyl Christian Walde <walde.christian@googlemail.com> Karen Etheridge
+<ether@cpan.org> Mike Doherty <doherty@cs.dal.ca> Olivier Mengué
+<dolmen@cpan.org>
 
 =head1 NAME
 
@@ -80,7 +78,7 @@ Dist::Zilla::Plugin::Git::CheckFor::CorrectBranch - Check that you're on the cor
 
 =head1 VERSION
 
-This document describes version 0.008 of Dist::Zilla::Plugin::Git::CheckFor::CorrectBranch - released November 10, 2013 as part of Dist-Zilla-PluginBundle-Git-CheckFor.
+This document describes version 0.009 of Dist::Zilla::Plugin::Git::CheckFor::CorrectBranch - released January 28, 2014 as part of Dist-Zilla-PluginBundle-Git-CheckFor.
 
 =head1 SYNOPSIS
 
